/***************************************************************************/
/* 	This code is part of X-toolkit widget library called Nws 	   */
/*	Copyright (c) 1997,1998,1999 Ondrejicka Stefan			   */
/*	(ondrej@idata.sk)						   */
/*	Distributed under GPL 2 or later				   */
/***************************************************************************/

#ifndef _MwMenuBar_H_
#define _MwMenuBar_H_

#include	"MwRow.h"

typedef struct _MwMenuBarClassRec		*MwMenuBarWidgetClass;
typedef struct _MwMenuBarRec		*MwMenuBarWidget;

extern WidgetClass mwMenuBarWidgetClass;

#endif
